@@ -743,3 +743,214 @@ class EduStatus(Base):
 
     def __str__(self):
         return f'{self.name_ru}'
+
+
+class SettlementStatus(Base):
+    """
+    Неизвестный модель
+    """
+    __tablename__ = 'univer_settlement_status'
+
+    # Идентификатор
+    id = Column('settlement_status_id', Integer, primary_key=True)
+
+    # Наименование
+    name_ru = Column('settlement_status_name_ru', String(100))
+    name_kz = Column('settlement_status_name_kz', String(100))
+    name_en = Column('settlement_status_name_en', String(100))
+
+    # Статус
+    status = Column(Integer)
+
+    @validates('status')
+    def validate_status(self, key, value):
+        """
+        Значением status могут быть следующие значения:
+        - 1 (Активный)
+        - 2 (Архивный)
+        """
+        assert value in [1, 2]
+        return value
+
+    def __repr__(self):
+        return f'<SettlementStatus {self} (id={self.id} status={self.status})>'
+
+    def __str__(self):
+        return f'{self.name_ru}'
+
+
+class ForeignLanguage(Base):
+    """
+    Иностранный язык
+    """
+    __tablename__ = 'univer_foreign_language'
+
+    # Идентификатор
+    id = Column('foreign_language_id', Integer, primary_key=True)
+
+    # Наименование
+    name_ru = Column('foreign_language_name_ru', String(100))
+    name_kz = Column('foreign_language_name_kz', String(100))
+    name_en = Column('foreign_language_name_en', String(100))
+
+    # Статус
+    status = Column(Integer)
+
+    @validates('status')
+    def validate_status(self, key, value):
+        """
+        Значением status могут быть следующие значения:
+        - 1 (Активный)
+        - 2 (Архивный)
+        """
+        assert value in [1, 2]
+        return value
+
+    def __repr__(self):
+        return f'<ForeignLanguage {self} (id={self.id} status={self.status})>'
+
+    def __str__(self):
+        return f'{self.name_ru}'
+
+
+class AdmissionReason(Base):
+    """
+    Причина поступления
+    """
+    __tablename__ = 'univer_admission_reason'
+
+    # Идентификатор
+    id = Column('admission_reason_id', Integer, primary_key=True)
+
+    # Наименование
+    name_ru = Column('admission_reason_name_ru', String(200))
+    name_kz = Column('admission_reason_name_kz', String(200))
+    name_en = Column('admission_reason_name_en', String(200))
+
+    # Статус
+    status = Column(Integer)
+
+    @validates('status')
+    def validate_status(self, key, value):
+        """
+        Значением status могут быть следующие значения:
+        - 1 (Активный)
+        - 2 (Архивный)
+        """
+        assert value in [1, 2]
+        return value
+
+    def __repr__(self):
+        return f'<AdmissionReason {self} (id={self.id} status={self.status})>'
+
+    def __str__(self):
+        return f'{self.name_ru}'
+
+
+class Region(Base):
+    """
+    Регион
+    """
+    __tablename__ = 'univer_region'
+
+    # Идентификатор
+    id = Column('region_id', Integer, primary_key=True)
+
+    # Наименование
+    name_ru = Column('region_name_ru', String(100))
+    name_kz = Column('region_name_kz', String(100))
+    name_en = Column('region_name_en', String(100))
+
+    # Короткое наименование
+    short_name_ru = Column('region_short_name_ru', String(100))
+    short_name_kz = Column('region_short_name_kz', String(100))
+    short_name_en = Column('region_short_name_en', String(100))
+
+    # Код региона
+    code = Column('region_code', Integer)
+
+    # Текущий регион
+    current = Column('current_region', Integer)
+
+    @validates('current')
+    def validate_current(self, key, value):
+        """
+        Значением current могут быть следующие значения:
+        - 0 (Не текущий)
+        - 1 (Текущий)
+        """
+        assert value in [0, 1]
+        return value
+
+    # Статус
+    status = Column(Integer)
+
+    @validates('status')
+    def valdate_status(self, key, value):
+        """
+        Значением status могут быть следующие значения:
+        - 1 (Активный)
+        - 2 (Архивный)
+        """
+        assert value in [1, 2]
+        return value
+
+    def __repr__(self):
+        return f'<Region {self} (id={self.id} status={self.status} current={self.current})>'
+
+    def __str__(self):
+        return f'{self.name_ru}'
+
+
+class District(Base):
+    """
+    Район
+    """
+    __tablename__ = 'univer_district'
+
+    # Идентификатор
+    id = Column('district_id', Integer, primary_key=True)
+
+    # Статус
+    status = Column(Integer)
+
+    @validates('status')
+    def validate_status(self, key, value):
+        """
+        Значением status могут быть следующие значения:
+        - 1 (Активный)
+        - 2 (Архивный)
+        """
+        assert value in [1, 2]
+        return value
+
+    # Регион
+    region_id = Column(ForeignKey('univer_region.region_id'))
+    region = relationship('Region')
+
+    # Наименование
+    name_ru = Column('district_name_ru', String())
+    name_kz = Column('district_name_kz', String())
+    name_en = Column('district_name_en', String())
+
+    # Код района
+    code = Column('district_code', Integer)
+
+    # Текущий район
+    current = Column('current_district', Integer)
+
+    @validates('current')
+    def validate_current(self, key, value):
+        """
+        Значением current могут быть следующие значения:
+        - 0 (Не текущий)
+        - 1 (Текущий)
+        """
+        assert value in [0, 1]
+        return value
+
+    def __repr__(self):
+        return f'<District {self} (id={self.id} status={self.status} current={self.current})>'
+
+    def __str__(self):
+        return f'{self.name_ru}'
